@@ -18,6 +18,7 @@
 #'  This can be used with shiny to tie updates to a selected table cell.
 #' @param width numeric table width
 #' @param height numeric table height
+#' @param digits numeric passed to \code{jsonlite::toJSON}
 #' @param ... passed to hot_table
 #' @examples
 #' library(rhandsontable)
@@ -32,7 +33,7 @@
 rhandsontable <- function(data, colHeaders, rowHeaders, comments = NULL,
                           useTypes = TRUE, readOnly = NULL,
                           selectCallback = FALSE,
-                          width = NULL, height = NULL, ...) {
+                          width = NULL, height = NULL, digits = 4, ...) {
   if (missing(colHeaders))
     colHeaders = colnames(data)
   if (missing(rowHeaders))
@@ -101,7 +102,8 @@ rhandsontable <- function(data, colHeaders, rowHeaders, comments = NULL,
   }
 
   x = list(
-    data = jsonlite::toJSON(data, na = "string", rownames = FALSE),
+    data = jsonlite::toJSON(data, na = "string", rownames = FALSE,
+                            digits = digits),
     rClass = rClass,
     rColClasses = rColClasses,
     rColnames = as.list(colnames(data)),
@@ -165,6 +167,7 @@ rhandsontable <- function(data, colHeaders, rowHeaders, comments = NULL,
 #' @param enableComments logical enabling comments in the table
 #' @param overflow character setting the css overflow behavior. Options are
 #'  auto (default), hidden and visible
+#' @param rowHeaderWidth numeric width (in px) for the rowHeader column
 #' @param ... passed to \href{http://handsontable.com}{Handsontable.js} constructor
 #' @examples
 #' library(rhandsontable)
@@ -180,11 +183,12 @@ rhandsontable <- function(data, colHeaders, rowHeaders, comments = NULL,
 hot_table = function(hot, contextMenu = TRUE, stretchH = "none",
                      customBorders = NULL, highlightRow = NULL,
                      highlightCol = NULL, enableComments = FALSE,
-                     overflow = NULL, ...) {
+                     overflow = NULL, rowHeaderWidth = NULL, ...) {
   if (!is.null(stretchH)) hot$x$stretchH = stretchH
   if (!is.null(customBorders)) hot$x$customBorders = customBorders
   if (!is.null(enableComments)) hot$x$comments = enableComments
   if (!is.null(overflow)) hot$x$overflow = overflow
+  if (!is.null(rowHeaderWidth)) hot$x$rowHeaderWidth = rowHeaderWidth
 
   if ((!is.null(highlightRow) && highlightRow) ||
       (!is.null(highlightCol) && highlightCol))
@@ -325,6 +329,7 @@ hot_context_menu = function(hot, allowRowEdit = TRUE, allowColEdit = TRUE,
 #' @param colWidths a scalar or numeric vector of column widths
 #' @param columnSorting logical enabling row sorting. Sorting only alters the
 #'  table presentation and the original dataset row order is maintained.
+#'  The sorting will be done when a user click on column name
 #' @param manualColumnMove logical enabling column drag-and-drop reordering
 #' @param manualColumnResize logical enabline column width resizing
 #' @param fixedColumnsLeft a numeric vector indicating which columns should be
@@ -392,6 +397,8 @@ hot_cols = function(hot, colWidths = NULL, columnSorting = NULL,
 #' @param dateFormat character defining the date format. See
 #'  {https://github.com/moment/moment}{Moment.js} for details.
 #' @param default default column value for new rows (NA if not specified; shiny only)
+#' @param language locale passed to \href{http://numeraljs.com}{Numeral.js};
+#'  default is 'en'.
 #' @param ... passed to handsontable
 #' @examples
 #' library(rhandsontable)
@@ -410,7 +417,7 @@ hot_col = function(hot, col, type = NULL, format = NULL, source = NULL,
                    strict = NULL, readOnly = NULL, validator = NULL,
                    allowInvalid = NULL, halign = NULL, valign = NULL,
                    renderer = NULL, copyable = NULL, dateFormat = NULL,
-                   default = NULL, ...) {
+                   default = NULL, language = NULL, ...) {
   cols = hot$x$columns
   if (is.null(cols)) {
     # create a columns list
@@ -432,6 +439,7 @@ hot_col = function(hot, col, type = NULL, format = NULL, source = NULL,
     if (!is.null(readOnly)) cols[[i]]$readOnly = readOnly
     if (!is.null(copyable)) cols[[i]]$copyable = copyable
     if (!is.null(default)) cols[[i]]$default = default
+    if (!is.null(language)) cols[[i]]$language = language
 
     if (!is.null(validator)) cols[[i]]$validator = JS(validator)
     if (!is.null(allowInvalid)) cols[[i]]$allowInvalid = allowInvalid
